
function Pandorum:LoadOptions(self) 
	local panel = CreateFrame("FRAME", "Pandorum_Options_Panel") 
 
	-- Name of the panel (How it appears in the list)
	panel.name = "Pandorum"
	
	-- Occurs when the player clicks "Okay"
	panel.okay = function() 
		for i, button in ipairs{panel:GetChildren()} do 
			button.origValue = storage[field] 
		end
		
		if PandorumDB.TooltipToCursor == true then
			function GameTooltip_SetDefaultAnchor(tooltip, parent)
				tooltip:SetOwner(parent, "ANCHOR_CURSOR")
			end
		else
			function GameTooltip_SetDefaultAnchor(tooltip, parent)
				tooltip:SetOwner(parent, "ANCHOR_BOTTOMRIGHT", -250, 150)
			end
		end
	end
	
	-- Occurs when the player clicks "Cancel"
	panel.cancel = function() 
		for i, button in ipairs{panel:GetChildren()} do 
			if button.Restore then
				button:Restore()
			end 
		end 
	end 

	-- Occurs when the player clicks the "Defaults" button. Good idea to reset all VarsDB to the default values.
	panel.default = function()
		PandorumDB.EasyDelete = true
		PandorumDB.lolHealthStone = true
		PandorumDB.Paranoia = true
		PandorumDB.TooltipToCursor = true
		PandorumDB.ExtraBar = true
		PandorumDB.TargetOfTarget = true
		PandorumDB.ScoreboardSummary = true
		PandorumDB.WhatHappened = true
		PandorumDB.LargerAuras = true
		PandorumDB.StatsDisplay = true
		PandorumDB.ImportantStuff = true
		PandorumDB.ChatFrame = true
		PandorumDB.AutoSellGrey = true
		InterfaceOptionsFrameOkay:Click()
	 end
 
	local f = Pandorum:CreateCheckButton("Quickly delete cursor item", panel, PandorumDB, "EasyDelete", PandorumL.EasyDelete, false) 
	f:SetPoint('TOPLEFT', 10, -30); local last = f
	f:SetScript('OnClick', function(self, button, down) PandorumDB.EasyDelete = not PandorumDB.EasyDelete
		if PandorumDB.EasyDelete == true then
			EasyDelete:CreateUpdate()
		end
	end)
	
	local Header = f:CreateFontString(nil, "BACKGROUND")
	Header:SetFontObject(GameFontNormalHuge)
	Header:SetWidth(400)
	Header:SetHeight(12)
	Header:SetPoint('TOPLEFT', 10, 20)
	Header:SetJustifyH("LEFT")
	Header:SetJustifyV("TOP")
	Header:SetText(panel.name)
	
	f = Pandorum:CreateCheckButton("Healthstone usage alert", panel, PandorumDB, "lolHealthStone", PandorumL.LOLHealthStone, false) 
	f:SetPoint('TOP', last, 'BOTTOM', 0, 0); last = f
	f:SetScript('OnClick', function(self, button, down) PandorumDB.lolHealthStone = not PandorumDB.lolHealthStone
		if PandorumDB.lolHealthStone == true then
			CreateHealthStoneFrame()
			HealthStoneIcon:RegisterEvent("UNIT_HEALTH")
			HealthStoneIcon:RegisterEvent("PLAYER_REGEN_ENABLED")
		end
	end)
	
	f = Pandorum:CreateCheckButton("Attach tooltip to cursor", panel, PandorumDB, "TooltipToCursor", PandorumL.TooltipToCursor, false) 
	f:SetPoint('TOP', last, 'BOTTOM', 0, 0); last = f
	f:SetScript('OnClick', function(self, button, down) PandorumDB.TooltipToCursor = not PandorumDB.TooltipToCursor
		TooltipToCursor:Toggle()
	end)
	
	f = Pandorum:CreateCheckButton("Target of tooltip target", panel, PandorumDB, "TargetOfTarget", PandorumL.TargetOfTarget, false) 
	f:SetPoint('TOP', last, 'BOTTOM', 0, 0); last = f
	
	f = Pandorum:CreateCheckButton("Name in chat paranoia", panel, PandorumDB, "Paranoia", PandorumL.Paranoia, false) 
	f:SetPoint('TOP', last, 'BOTTOM', 0, 0); last = f
	f:SetScript('OnClick', function(self, button, down) PandorumDB.Paranoia = not PandorumDB.Paranoia
		if PandorumDB.Paranoia == true then
			Paranoia:RegisterEvents()
		end
	end)
	
	f = Pandorum:CreateCheckButton("Extra Bar", panel, PandorumDB, "ExtraBar", PandorumL.ExtraBar, false) 
	f:SetPoint('TOP', last, 'BOTTOM', 0, 0); last = f
	f:SetScript('OnClick', function(self, button, down) PandorumDB.ExtraBar = not PandorumDB.ExtraBar
		if PandorumDB.ExtraBar == true then
			ExtraBar:CreateExtraBar()
		else
			local dummy = function() end
			for i = 1, 12 do 
				local BUTTON = _G["ExtraBar"..i]
				if BUTTON then  BUTTON.Show = dummy; BUTTON:Hide(); end
			end
			ExtraBar:UnregisterEvent("PET_BAR_HIDE")
			ExtraBar:UnregisterEvent("UNIT_PET")
			if PetActionBarFrame:IsVisible() then
				if ShapeshiftBarFrame:IsVisible() then
					PetActionBarFrame:ClearAllPoints(); PetActionBarFrame:SetPoint("BOTTOMLEFT", MultiBarBottomRightButton1, "TOPLEFT", 0, 6)
				else
					PetActionBarFrame:ClearAllPoints(); PetActionBarFrame:SetPoint("BOTTOMLEFT", MultiBarBottomLeftButton1, "TOPLEFT", 0, 6)
				end
			end
		end
	end)
	
	f = Pandorum:CreateCheckButton("Scoreboard summary in BG's", panel, PandorumDB, "ScoreboardSummary", PandorumL.ScoreboardSummary, false) 
	f:SetPoint('TOP', last, 'BOTTOM', 0, 0); last = f
	f:SetScript('OnClick', function(self, button, down) PandorumDB.ScoreboardSummary = not PandorumDB.ScoreboardSummary
		if PandorumDB.ScoreboardSummary == true then
			Pandorum:CreateScoreboard()
			for i = 1, 12 do
				local f = _G["Summary_"..i]
				if f then
					f:SetParent(WorldStateScoreFrame); f:Show()
				end
			end
			
		else
			ScoreboardSummary_Updater:SetScript('OnUpdate', nil)
			for i = 1, 12 do
				local f = _G["Summary_"..i]
				if f then
					f:SetParent(UIParent); f:Hide()
				end
			end
		end
	end)
	
	f = Pandorum:CreateCheckButton("Large auras on target frame", panel, PandorumDB, "LargerAuras", PandorumL.LargerAuras, false) 
	f:SetPoint('TOP', last, 'BOTTOM', 0, 0); last = f
	f:SetScript('OnClick', function(self, button, down) PandorumDB.LargerAuras = not PandorumDB.LargerAuras
		if PandorumDB.LargerAuras == true then
			LargeAuras:RegisterEvent("UNIT_AURA")
		end
	end)
	
	f = Pandorum:CreateCheckButton("Happy Coil (Warlock)", panel, PandorumDB, "HappyCoil", PandorumL.HappyCoil, false) 
	f:SetPoint('TOP', last, 'BOTTOM', 0, 0); last = f
	f:SetScript('OnClick', function(self, button, down) PandorumDB.HappyCoil = not PandorumDB.HappyCoil
		if PandorumDB.HappyCoil == true then
			HappyCoil:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
			HappyCoil:Show()
		else
			HappyCoil:SetScript('OnEvent', nil);
			HappyCoil:Hide();
		end
	end)
	
	f = Pandorum:CreateCheckButton("Auto sell grey items", panel, PandorumDB, "AutoSellGrey", PandorumL.AutoSellGrey, false) 
	f:SetPoint('TOP', last, 'BOTTOM', 0, 0); last = f
	
	local CommandList = f:CreateFontString(nil, "BACKGROUND")
	CommandList:SetFontObject(GameFontNormal)
	CommandList:SetWidth(400)
	CommandList:SetHeight(400)
	CommandList:SetPoint('TOPLEFT', 10, -30)
	CommandList:SetJustifyH("LEFT")
	CommandList:SetJustifyV("TOP")
	CommandList:SetText("Command list:|cffffffff\n/Pandorum\n/pand\n\n/randompet\n\n/de -- disable effects, used in macros\n/ee -- enable effects, used in macros")
	
	--[[ New row starts here ]]
	f = Pandorum:CreateCheckButton("Class specific buff alerts", panel, PandorumDB, "ImportantStuff", PandorumL.ImportantStuff, false) 
	f:SetPoint('TOPLEFT', 225, -30); last = f
	f:SetScript('OnClick', function(self, button, down) PandorumDB.ImportantStuff = not PandorumDB.ImportantStuff
		if PandorumDB.ImportantStuff == true then
			CreateImportantStuff()
			ImportantStuffEvents:RegisterEvent("UNIT_AURA")
			ImportantStuffEvents:Show()
		else
			ImportantStuff:Hide();
			ImportantStuffEvents:SetScript('OnEvent', nil);
			ImportantStuffEvents:Hide();
		end
	end)
	
	
	InterfaceOptions_AddCategory(panel) 
end 

function Pandorum:CreateCheckButton(name, parent, storage, field, locale, radio) 
	local button
	if radio then
		button = CreateFrame('CheckButton', parent:GetName() .. field, parent, 'SendMailRadioButtonTemplate')
	else
		button = CreateFrame('CheckButton', parent:GetName() .. field, parent, 'OptionsCheckButtonTemplate')
	end
	
	local frame = _G[button:GetName() .. 'Text']
	frame:SetText(name)
	frame:SetTextColor(1, 1, 1, 1)
	frame:SetFontObject(GameFontNormal)
	
	button:SetScript("OnShow", 
		function (self) 
			self:SetChecked(storage[field])  
			--self.origValue = storage[field] ~= nil and storage[field] or self.origValue
			self.origValue = storage[field]
		end 
	)

	if radio then
		button:SetScript("OnClick", 
			function (self, button, down)
				_G["Pandorum_Options_PanelUse alert.wav"]:SetChecked(nil)
				_G["Pandorum_Options_PanelUse a random in-game sound"]:SetChecked(nil)
				
				PandorumDB.TimeUntilAFK.Alert = false
				PandorumDB.TimeUntilAFK.Random = false
				
				this:SetChecked(1)
				storage[field] = not storage[field]
			end 
		)
	else
		button:SetScript("OnClick", 
			function (self, button, down) 
				storage[field] = not storage[field]
			end
		)
	end	
	
	button:SetScript("OnEnter",
		function ()
			GameTooltip:ClearLines()
			GameTooltip:SetOwner(TargetFrame, "ANCHOR_CURSOR")
			GameTooltip:SetText(locale[1])
			GameTooltip:AddLine(locale[2], 1, 1, 1)
			GameTooltip:Show()
		end
	)

	function button:Restore() 
		if self.origValue ~= nil then storage[field] = self.origValue end
	end 
	
	return button 
end

function Pandorum:CreateSlider(text, parent, low, high, step, storage, field)
	local name = parent:GetName() .. text
	local slider = CreateFrame('Slider', name, parent, 'OptionsSliderTemplate')
	slider:SetScript('OnMouseWheel', Slider_OnMouseWheel)
	slider:SetMinMaxValues(low, high)
	slider:SetValueStep(step)
	slider:EnableMouseWheel(true)

	_G[name .. 'Text']:SetText(text)
	_G[name .. 'Low']:SetText('')
	_G[name .. 'High']:SetText('')

	local text = slider:CreateFontString(nil, 'BACKGROUND')
	text:SetFontObject('GameFontHighlightSmall')
	text:SetPoint('LEFT', slider, 'RIGHT', 7, 0)
	slider.valText = text
	
	slider:SetScript('OnShow', function(self)
		self.origValue = storage[field]
		self.onShow = true
		self:SetValue(storage[field])
		self.onShow = nil
	end)
	
	function slider:Restore() 
		storage[field] = self.origValue 
	end 

	return slider
end

function Pandorum:CreateButton(name, parent, width, height)
	local button = CreateFrame('Button', parent:GetName() .. name, parent, 'UIPanelButtonTemplate')
	button:SetWidth(width)
	button:SetHeight(height)
	
	local frame = _G[button:GetName() .. 'Text']
	frame:SetText(name)
	frame:SetTextColor(1, 1, 1, 1)

	return button 
end