local db = knUI_DB

--[[ The code below is nearly all from ncUI ]]
local mult = 768/string.match(GetCVar("gxResolution"), "%d+x(%d+)")/.64

local function scale(x)
    return mult*math.floor(x/mult+.5)
end

local function kill() end

local function UpdateLFG()
	MiniMapLFGFrame:ClearAllPoints(); MiniMapLFGFrame:SetPoint("BottomLeft", Minimap, "BottomLeft", -5, -5)
end

local function color(pvpType)
	if pvpType == "friendly" or pvpType == "sanctuary" then
		return "|cff146093" -- blue
	elseif pvpType == "nil" then
		return "|cffC2D2DD" -- white
	else
		return "|cffC53838" -- red
	end
end

if db["Minimap"].Enabled then


	--[[ The Zone Text block ]]
	local tmp = db["Minimap"]
	CreateFrame("Frame", "ZoneText", Minimap)
	knUI:CreatePanel(ZoneText, tmp.Width, tmp.Height)
	ZoneText:SetPoint(tmp["ZoneAnchors"][1], _G[tmp["ZoneAnchors"][2]], tmp["ZoneAnchors"][3], tmp["ZoneAnchors"][4], tmp["ZoneAnchors"][5])
	ZoneText:EnableMouse(true)
	ZoneText:SetFrameLevel(10) -- Forces the frame to be above the minimap cluster

	ZoneText:SetScript("OnLeave", function(self, event, ...) GameTooltip:Hide() end)
	ZoneText:SetScript("OnEnter", function(self, event, ...)
		local pvpType, isSubZonePVP, factionName = GetZonePVPInfo()
		GameTooltip:SetOwner(ZoneText, "ANCHOR_CURSOR");
		GameTooltip:SetText(GetMinimapZoneText().."\n"..GetZoneText().." ("..pvpType..")");
		GameTooltip:Show()
	end)

	local t = ZoneText:CreateFontString(nil, "OVERLAY")
		t:SetFont(tmp["Font"][1], tmp["Font"][2])
		t:SetPoint("CENTER", 1, 0)
		ZoneText.Text = t

	ZoneText:RegisterEvent("ZONE_CHANGED")
	ZoneText:RegisterEvent("ZONE_CHANGED_INDOORS")
	ZoneText:RegisterEvent("ZONE_CHANGED_NEW_AREA")
	ZoneText:SetScript("OnEvent", function(self, event, ...) knUI:UpdateMinimapZoneText() end)

	function knUI:UpdateMinimapZoneText()
		-- Create a table to store each word in the zone text one entry at a time
		local words = {}
		
		-- The zone text
		local text = GetMinimapZoneText() or GetZoneText() or "Unknown"
		
		-- Remove the trailing space
		text = strtrim(text, " ")
		
		-- Cound the spaces in the zone text, this determines how many words
		local count = (select(2, string.gsub(text, " ", "%0")))
		
		-- Add one, I don't remember why...
		count = count + 1
		
		-- Insert the words into the table, removing any spaces
		for i = 1, count do
			table.insert(words, (select(i, strsplit(" ", text))).." ")
		end
		
		-- If there is more than one word....
		if count > 1 then
			-- If it's more than 4 words, initialize all words more than 2 characters
			if count > 4 then
				for i = 1, count do
					if string.len(tostring(words[i])) > 2 then
						-- Insert the initialized word with a space after it
						table.insert(words, i, string.sub(words[i], 0, 1)..". ")
						-- Remove the old word
						table.remove(words, i + 1)
					end
				end
			else
				-- If it's less than 4 words
				for i = 1, count do
					-- And that word is more than 7 characters
					if string.len(tostring(words[i])) > 7 then
						-- Insert the initialized word with a space after it
						table.insert(words, i, string.sub(words[i], 0, 1)..". ")
						-- Remove the old word
						table.remove(words, i + 1)
					end
				end
			end
		else
			-- If it's a single word, and it's longer than 15 characters, omit all after 15, add ...
			if string.len(tostring(words[1])) > 15 then
				-- Insert the new word to the table
				table.insert(words, 1, string.sub(words[1], 0, 15).."...")
				-- Remove the old word
				table.remove(words, i + 1)
			end
		end
		
		-- What type of zone is it? color approporiately
		local pvpType, isSubZonePVP, factionName = GetZonePVPInfo()
		
		-- Set the text
		ZoneText.Text:SetText(color(pvpType)..table.concat(words))
	end
	
	Minimap:SetMaskTexture([[Interface\AddOns\knUI\resources\graphics\mask]])
	Minimap:SetFrameStrata("BACKGROUND")
	Minimap:ClearAllPoints()
	Minimap:SetPoint(tmp["MapAnchors"][1], _G[tmp["MapAnchors"][2]], tmp["MapAnchors"][3], tmp["MapAnchors"][4], tmp["MapAnchors"][5])
	Minimap:SetWidth(145)
	Minimap:SetHeight(145)
	
	CreateFrame("Frame", "MapBorder", Minimap)
	knUI:CreatePanel(MapBorder, 145, 145, "CENTER", Minimap, "CENTER", 0, 0)
	MapBorder:ClearAllPoints()
	MapBorder:SetPoint("TOPLEFT", scale(-4), scale(4))
	MapBorder:SetPoint("BOTTOMRIGHT", scale(3), scale(-3))

	MinimapBorder:Hide()
	MinimapBorderTop:Hide()

	MinimapZoomIn:Hide()
	MinimapZoomOut:Hide()
	MiniMapMailBorder:Hide()

	MinimapNorthTag.Show = kill

	MinimapNorthTag:Hide()
	MiniMapWorldMapButton:Hide()
	MiniMapWorldMapButton:UnregisterAllEvents()

	MiniMapBattlefieldFrame:ClearAllPoints(); MiniMapBattlefieldFrame:SetPoint("BottomLeft", Minimap, "BottomLeft", -5, -5)

	MiniMapInstanceDifficulty:SetParent(Minimap)
	MiniMapInstanceDifficulty:ClearAllPoints(); MiniMapInstanceDifficulty:SetPoint("TOPLEFT", Minimap, "TOPLEFT", -7, 10)

	GuildInstanceDifficulty:SetParent(Minimap)
	GuildInstanceDifficulty:ClearAllPoints(); GuildInstanceDifficulty:SetPoint("TOPLEFT", Minimap, "TOPLEFT", -7, 10)
	
	GameTimeFrame:Hide()
	MinimapZoneTextButton:Hide()
	MinimapZoneTextButton:UnregisterAllEvents()
	
	hooksecurefunc("MiniMapLFG_UpdateIsShown", UpdateLFG)
	Minimap:EnableMouseWheel(true)

	Minimap:SetScript("OnMouseWheel", function(self, d)
		if d > 0 then
			_G.MinimapZoomIn:Click()
		elseif d < 0 then
			_G.MinimapZoomOut:Click()
		end
	end)

	Minimap:SetScript("OnMouseUp", function(self, btn)
		if btn == "RightButton" then
			ToggleDropDownMenu(1, nil, MiniMapTrackingDropDown, self)
		elseif btn == "MiddleButton" then
			GameTimeFrame:Click() 
		else
			Minimap_OnClick(self)
		end
	end)
	

	--[[ Server time block ]]
	CreateFrame("Frame", "MinimapTime", Minimap)
	knUI:CreatePanel(MinimapTime, (tmp.Width / 2) - 1, tmp.Height)
	MinimapTime:SetPoint(tmp["TimeAnchors"][1], _G[tmp["TimeAnchors"][2]], tmp["TimeAnchors"][3], tmp["TimeAnchors"][4], tmp["TimeAnchors"][5])
	MinimapTime:EnableMouse(true)

	MinimapTime.e = 1

	local text  = MinimapTime:CreateFontString(nil, "OVERLAY")
		text:SetFont(tmp["Font"][1], tmp["Font"][2])
		text:SetPoint("CENTER", 1, 0)

	local function Update(self, e)
		local pending = CalendarGetNumPendingInvites()
		MinimapTime.e = MinimapTime.e - e
		if MinimapTime.e < 0 then
			local Hr, Min = GetGameTime()
			if Hr == 0 then Hr = 12 end
			if Min < 10 then Min = "0"..Min end
          
			if Hr >= 12 then
				if Hr > 12 then Hr = Hr - 12 end
				
				if pending > 0 then
					text:SetText("|cffD4D4D4"..Hr..":"..Min.."pm")
				else
					text:SetText(Hr..":"..Min.."pm")
				end
			else
				if pending > 0 then
					text:SetText("|cffD4D4D4"..Hr..":"..Min.."am")
				else
					text:SetText(Hr..":"..Min.."am")
				end
			end
			MinimapTime.e = 1
		end
	end

	local SecondsToReadable = function(seconds) 
		local hour = tonumber(format("%01.f", floor(seconds/3600)))
		local min = format(hour>0 and "%02.f" or "%01.f", floor(seconds/60 - (hour*60)))
		local sec = format("%02.f", floor(seconds - hour*3600 - min *60))
		return (hour>0 and hour..":" or "")..min..":"..sec
	end
	
	MinimapTime:SetScript("OnEnter", function(self)
		if not InCombatLockdown() then
			GameTooltip:SetOwner(MinimapTime, "ANCHOR_CURSOR")
			GameTooltip:ClearLines()
			
			local WGpvpID, WGlocalizedName, WGisActive, WGcanQueue, WGwaitTime, WGcanEnter = GetWorldPVPAreaInfo(1) -- Wintergrasp
			local TBpvpID, TBlocalizedName, TBisActive, TBcanQueue, TBwaitTime, TBcanEnter = GetWorldPVPAreaInfo(2) -- Tol Barad
			
			GameTooltip:AddDoubleLine("|cffffffffLocation", "|cffffffffhh:mm:ss")
			GameTooltip:AddDoubleLine("Time to "..WGlocalizedName..":",SecondsToReadable(WGwaitTime))
			GameTooltip:AddDoubleLine("Time to "..TBlocalizedName..":",SecondsToReadable(TBwaitTime))
			GameTooltip:Show()
		end	
	end)
	
	MinimapTime:SetScript("OnLeave", function() GameTooltip:Hide() end)
	
	MinimapTime:RegisterEvent("CALENDAR_UPDATE_PENDING_INVITES")
	MinimapTime:RegisterEvent("PLAYER_ENTERING_WORLD")
	MinimapTime:SetScript("OnUpdate", Update)
	MinimapTime:SetScript("OnMouseDown", function() GameTimeFrame:Click() end)
	Update(MinimapTime, 10)
	
	
	--[[ Important stat block ]]
	CreateFrame("Frame", "MinimapStat", Minimap)
	knUI:CreatePanel(MinimapStat, (tmp.Width / 2) - 1, tmp.Height)
	MinimapStat:SetPoint(tmp["StatAnchors"][1], _G[tmp["StatAnchors"][2]], tmp["StatAnchors"][3], tmp["StatAnchors"][4], tmp["StatAnchors"][5])
	
	local t = MinimapStat:CreateFontString(nil, "OVERLAY")
	t:SetFont(tmp["Font"][1], tmp["Font"][2])
	t:SetPoint("CENTER", MinimapStat)
	t:SetTextColor(.6, .6, .6, 1)
	MinimapStat.Text = t

end