local interval = 0
local PlayerName = UnitName('player')
local classes = { "DEATHKNIGHT", "DRUID", "HUNTER", "MAGE", "PALADIN", "PRIEST", "ROGUE", "SHAMAN", "WARLOCK", "WARRIOR", "SERVERS", "PLAYER" }
local TooltipText = {
	"The fearsome death knight, World of Warcraft's first Hero class, is not your average adventurer seeking to prove his or her worth on Azeroth's fields of battle.",
	"Druids are the keepers of the world and masters of nature with a diverse array of abilities.",
	"Hunters are deadly marksmen, capable of bringing their enemies down from a distance with bows or rifles.",
	"Mages wield the elements of fire, frost, and the arcane to destroy or neutralize their enemies.",
	"Guardians of the Holy Light, paladins bolster their allies with holy auras and blessing to protect their friends from harm and enhance their powers.",
	"Priests are the masters of healing and preservation, restoring their wounded allies, shielding them in battle, and even resurrecting their fallen comrades.",
	"Rogues are a lightly armored melee class capable of dealing massive damage to their enemies in a flurry of attacks.",
	"Shaman are the spiritual leaders of their tribes and clans. They are masters of the elements, using spells and totems that heal or enhance their allies in battle while unleashing the fury of the elements upon their foes.",
	"Warlocks are masters of shadow, flame, and demonic power. They are a robed class that excels at plaguing their enemies with disease or curses, hurling bolts of fire or shadow energy across the battlefield, and summoning demons to aid them in combat.",
	"Warriors can be a raging berserker or an iron-clad juggernaut, capable of withstanding tremendous attacks while protecting their allies from harm.",
	"The total amount of servers on each team. Useful to determine if you're up against a premade.",
	"Your killing blows & total honor earned.",
}

local ClassCoords = {
	"Spell_Deathknight_ClassIcon.blp",
	"Ability_Druid_Maul.blp",
	"INV_Weapon_Bow_07.blp",
	"INV_Staff_13.blp",
	"INV_Hammer_01.blp",
	"INV_Staff_30.blp",
	"INV_ThrowingKnife_04.blp",
	"Spell_Nature_BloodLust.blp",
	"Spell_Nature_Drowsy.blp",
	"INV_Sword_27.blp",
	"INV_Misc_Food_148_CupCake.blp",
	"INV_Misc_Food_148_CupCake.blp",
}

if not knUI_DB.ScoreboardSummary then
	return
else
	local last = nil
	for i = 1, 12 do
		local f = CreateFrame("Frame", "Summary_"..i, WorldStateScoreFrame)
		f:SetWidth(64)
		f:SetHeight(32)
		f.Class = classes[i]
		f:SetFrameLevel(0)
		
		if i == 1 then
			f:SetPoint("BOTTOMLEFT", WorldStateScoreFrame, "TOPLEFT", 15, 0)
			last = f
		else
			f:SetPoint("LEFT", last, "RIGHT", 0, 0)
			last = f
		end

		local t = f:CreateTexture(nil,"BACKGROUND")
			t:SetTexture("Interface\\Addons\\knUI\\resources\\graphics\\tab.tga")
			t:SetAllPoints(f)
			f.texture = t
		
		local txt = f:CreateFontString(nil, "BACKGROUND")
		txt:SetFontObject(GameFontNormalSmall)
		txt:SetWidth(64); txt:SetHeight(32)
		txt:SetPoint("CENTER", f, "CENTER", 10, 0)
		txt:SetJustifyH("MIDDLE"); txt:SetJustifyV("MIDDLE")
		txt:SetParent(f)
		f.Text = txt
		
		f:EnableMouse(true)
		f:SetScript("OnEnter", function() GameTooltip:SetOwner(f, "ANCHOR_CURSOR"); GameTooltip:SetText(TooltipText[i], 1, 1, 1, 1, 1)end)
		f:SetScript("OnLeave", function() GameTooltip:Hide() end)
		
		--[[ Create the class icon graphics for each frame ]]
		local fa = CreateFrame("Frame", "Summary_"..i.."Class", WorldStateScoreFrame)
			fa:SetWidth(32)
			fa:SetHeight(32)
			fa:SetPoint("LEFT", "Summary_"..i, "LEFT", 8, 0)
			fa:SetScale(.7)
			fa:SetFrameLevel(10)
		
		t = fa:CreateTexture(nil,"BACKGROUND")
			t:SetTexture("Interface\\ICONS\\"..ClassCoords[i])
			t:SetAllPoints(fa)
			fa.texture = t
	end
	
	Summary_12Class:Hide()
	Summary_12.Text:ClearAllPoints()
	Summary_12.Text:SetPoint("CENTER", Summary_12, "CENTER", 0, 0)
end

CreateFrame("Frame", "ScoreboardSummary_Updater", WorldStateScoreFrame)
ScoreboardSummary_Updater:SetScript("OnUpdate", function(self, elapsed)
	interval = interval - elapsed
	if interval <= 0 then
		allyServers, hordeServers, servertmp = {}, {}, nil
		local SummaryHorde = { DEATHKNIGHT = 0, DRUID = 0, HUNTER = 0, MAGE = 0, PALADIN = 0, PRIEST = 0, ROGUE = 0, SHAMAN = 0, WARLOCK = 0, WARRIOR = 0 }
		local SummaryAlliance = { DEATHKNIGHT = 0, DRUID = 0, HUNTER = 0, MAGE = 0, PALADIN = 0, PRIEST = 0, ROGUE = 0, SHAMAN = 0, WARLOCK = 0, WARRIOR = 0 }
		
		for i = 1, GetNumBattlefieldScores() do
			local name, killingBlows, honorableKills, deaths, honorGained, faction, rank, race, classToken, damageDone, healingDone = GetBattlefieldScore(i)

			--if not classToken then break end
			
			if name == PlayerName then
				Summary_12.Text:SetText('|cffff0033'..killingBlows..'\n|cffffff66'..format("%.1f", honorGained))
			end
			
			if faction == 1 then
				SummaryAlliance[classToken] = SummaryAlliance[classToken] + 1
				
				if (not string.find(name, "-")) then
					servertmp = GetRealmName()
				else 
					_, servertmp = strsplit("-", name, 2)
				end
				
				if (allyServers[servertmp] == nil) then
					table.insert(allyServers, servertmp)
					allyServers[servertmp] = 1
				end
				
			else
				SummaryHorde[classToken] = SummaryHorde[classToken] + 1
				
				if (not string.find(name, "-")) then
					servertmp = GetRealmName()
				else 
					_, servertmp = strsplit("-", name, 2)
				end
				
				if (hordeServers[servertmp] == nil) then
					table.insert(hordeServers, servertmp)
					hordeServers[servertmp] = 1
				end
				
			end
		end
		
		for i = 1, 10 do
			local f = _G["Summary_"..i]
			f.Text:SetText('|cff3399ff'..SummaryAlliance[f.Class]..'\n|cffff0000'..SummaryHorde[f.Class])
		end
		
		Summary_11.Text:SetText('|cff3399ff'..#allyServers..'\n|cffff0000'..#hordeServers)
		
		interval = 1
	end
end)