local label, stat = "|cff999999", "|cffffffff"
local _, class = UnitClass("player")
local PlayerName, PlayerLevel = GetUnitName("player"), UnitLevel("player")

-- GET THE HIGHEST SPELL DAMAGE NUMBER
local function HighestDamageSchool()
    local holySchool = 2
    local biggest = 0
    for i=(holySchool+1), MAX_SPELL_SCHOOLS do
        local damage = GetSpellBonusDamage(i)
        biggest = max(biggest, damage)
    end
    return biggest
end


--[[ #########################
           Writes either spellpower, ap, rap, or avoidance to the small frame below the map
	########################## ]]
function knUI:Write(role)
	if role == "spell_dps" then
		MinimapStat.Text:SetText(stat..HighestDamageSchool()..label.." sp")
	elseif role == "healer" then
		MinimapStat.Text:SetText(stat..HighestDamageSchool()..label.." sp")
	elseif role == "melee" then
        local base, posBuff, negBuff = UnitAttackPower("player")	
        local AttackPower = base + posBuff + negBuff
		MinimapStat.Text:SetText(stat..AttackPower..label.." ap")
	elseif role == "ranged" then
        local base, posBuff, negBuff = UnitRangedAttackPower("player")		
        local AttackPower = base + posBuff + negBuff
		MinimapStat.Text:SetText(stat..AttackPower..label.." rap")
	elseif role == "tank" then
		MinimapStat.Text:SetText(stat..format("%.1f", GetDodgeChance()+GetParryChance()+GetBlockChance()).."%"..label.." avo")
	end
end


--[[ #########################
           Updates guild member information and displays it on game tooltip
		   I added this because of EPGP forcing that damned checkbox.
	########################## ]]
local colorlvl = function(level)
	if level < PlayerLevel then
		if 6 <= (PlayerLevel - level) then return "|cffD4D4D4"..level end
		return "|cff9BEDA7"..level
	elseif PlayerLevel == level then
		return "|cffffffff"..level
	elseif PlayerLevel < level then
		return "|cffC73C3C"..level
	else
		return "|cffff0000"..level
	end
end

function knUI:UpdateGuildInfo()
	if GameTooltip:IsVisible() then return end
	local class_colors = { DEATHKNIGHT = "|cff9E0240", DRUID = "|cffDA8B1B", HUNTER = "|cff2BB52E", MAGE = "|cff49A3D2", PALADIN = "|cffFF86D0", PRIEST = "|cffffffff", ROGUE = "|cffF2F46F", SHAMAN = "|cff1C85FA", WARLOCK = "|cffA33CD3", WARRIOR = "|cff895819" }

	-- Anchor the tooltip to the cursor
	GameTooltip:SetOwner(InfoLeft, "ANCHOR_CURSOR")
	GameTooltip:AddDoubleLine("Guild Member & Level", "Zone")
	
	-- Update the guild roster information
	GuildRoster()
	
	-- Scan the guild roster, for every online member, write their name, level, and current zone
	for i = 1, GetNumGuildMembers() do
		local name, rank, rankIndex, level, class, zone, note, officernote, online, status, classFileName, achievementPoints, achievementRank, isMobile = GetGuildRosterInfo(i)
		if online then
			GameTooltip:AddDoubleLine(colorlvl(level).." "..class_colors[classFileName]..name, stat..zone)
		end
	end
	
	GameTooltip:Show()
end

--[[ #########################
           Updates the addon usage, using game tooltip
	########################## ]]
local colorlag = function(number)
	if number <= 100 then
		return "|cff49EE61"
	elseif number <= 200 then
		return "|cffEFBF2B"
	else
		return "|cffFD2E2E"
	end
end

local colorfps = function(number)
	if number >= 30 then
		return "|cff49EE61"
	elseif number < 30 then
		return "|cffEFBF2B"
	elseif number < 15 then
		return "|cffFD2E2E"
	end
end

local function colormemory(number)
	local number = tonumber(number)
	if number >= 5120 then
		number = format("%.1f", number/1024)
		return "|cffFD2E2E"..number.."Mb"
	elseif number >= 1024 then
		return "|cffEFBF2B"..number.."Kb"
	else
		return number.."Kb"
	end
end

function knUI:UpdatePCStats()
	if GameTooltip:IsVisible() then return end
	local addons = {}
	local index = 1
	
	for i = 1, GetNumAddOns() do
		local name, title, notes, enabled, loadable, reason, security = GetAddOnInfo(i)
		local memory = GetAddOnMemoryUsage(i)
		
		if memory > 1024 then
			memory = format("%.0f", memory) or 0
			addons[index] = {}
			table.insert(addons[index], name)
			table.insert(addons[index], colormemory(memory))
			index = index + 1
		end
		
	end
	
	GameTooltip:SetOwner(InfoRight, "ANCHOR_CURSOR")
	GameTooltip:AddDoubleLine("|cffffffff"..knUIL.Latency[2], "|cffffffff"..knUIL.Latency[3])
	
	for i = 1, #addons do
		GameTooltip:AddDoubleLine(addons[i][1], addons[i][2])
	end
	
	GameTooltip:Show()
end

--[[ #########################
           Updates the Guild members online, Friends, and armor status.
	########################## ]]
CreateFrame("Frame", "knUI_OnEvent", UIParent)

knUI_OnEvent:RegisterEvent("UPDATE_INVENTORY_DURABILITY")
knUI_OnEvent:RegisterEvent("ADDON_LOADED")
knUI_OnEvent:RegisterEvent("PLAYER_ENTERING_WORLD")
knUI_OnEvent:RegisterEvent("BN_FRIEND_ACCOUNT_OFFLINE")
knUI_OnEvent:RegisterEvent("BN_FRIEND_ACCOUNT_ONLINE")
knUI_OnEvent:RegisterEvent("GUILD_ROSTER_UPDATE")

knUI_OnEvent:SetScript("OnEvent", function(self, event, ...)
	if (event == "ADDON_LOADED" and (...) ~= "knUI") then return end
	
	InfoLeft.LeftText:SetText(label.."Guild: "..stat..(select(2, GetNumGuildMembers())))
	InfoLeft.RightText:SetText(label.."Friends: "..stat..(select(2, BNGetNumFriends())) + (select(2, GetNumFriends())))
		
	local slot = 1
	local totalCurrent, totalMax = 0, 0
	
	while GetInventoryItemDurability(slot) do
		local current, maximum = GetInventoryItemDurability(slot)
		if current == nil then break end
		totalCurrent = totalCurrent + current
		totalMax = totalMax + maximum
		slot = slot + 1
	end
	
	InfoLeft.CenterText:SetText("Armor "..stat..format("%.0f", (totalCurrent / totalMax * 100)).."%")
end)


--[[ #########################
           Updates the FPS, latency, and memory usage
	########################## ]]
local i = 1
CreateFrame("Frame", "knUI_OnUpdate", UIParent)
knUI_OnUpdate:SetScript("OnUpdate", function(self, elapsed)
	i = i - elapsed
	if i <= 0 then
	
		if knUI_SPEC == nil then knUI_SPEC = knUI:ReadTalentSpec() end
		knUI:Write(knUI_SPEC)
		
		UpdateAddOnMemoryUsage()
		local fps = GetFramerate()
		local home = select(3,GetNetStats())
		local world = select(4,GetNetStats())
		local TotalMemoryUsed = 0
		
		for i = 1, GetNumAddOns() do
			local memory = GetAddOnMemoryUsage(i)
			TotalMemoryUsed = TotalMemoryUsed + memory
		end

		
		InfoRight.LeftText:SetText(string.format("%s%d|r|cffffffff fps", colorfps(fps), fps).." ")
		InfoRight.CenterText:SetText(string.format("%s%d|r|cffffffffms"..label.." home, %s%d|r|cffffffffms"..label.." world", colorlag(home), home, colorlag(world), world))
		InfoRight.RightText:SetText(label.."addon usage: "..stat..format("%.2f", TotalMemoryUsed/1024).."Mb")

			
		i = 3 -- Update UI text fields every 3 seconds
	end
end)
