if not knUI_DB.Tooltip then return end
local class_colors = { DEATHKNIGHT = "|cff9E0240", DRUID = "|cffDA8B1B", HUNTER = "|cff2BB52E", MAGE = "|cff49A3D2", PALADIN = "|cffFF86D0", PRIEST = "|cffffffff", ROGUE = "|cffF2F46F", SHAMAN = "|cff1C85FA", WARLOCK = "|cffA33CD3", WARRIOR = "|cff895819" }
local PlayerName, PlayerLevel = GetUnitName("player"), UnitLevel("player")

-- Create the icons to be shown
for i = 1, 2 do
	local allegance
	if i == 1 then allegance = "Horde" else allegance = "Alliance" end
	local f = CreateFrame("Frame", allegance.."Icon", UIParent)
	f:SetPoint("TopRight", GameTooltip, "TopLeft", 0, 0)
	f:SetWidth(35); f:SetHeight(35)

	f:SetBackdrop({
	  bgFile = "Interface\\PVPFrame\\PVP-Currency-"..allegance, 
	  edgeFile = "", 
	  
	  tile = false, tileSize = 0, edgeSize = 1,
	  insets = { left = 1, right = 1, top = 1, bottom = 1}
	})
	f:Hide()
end

-- Color the level
local colorlvl = function(level)
	if level == -1 then return "|cffC73C3C??" end
	
	if level < PlayerLevel then
		if 6 <= (PlayerLevel - level) then return "|cffD4D4D4"..level end
		return "|cff9BEDA7"..level
	elseif PlayerLevel == level then
		return "|cffffffff"..level
	elseif PlayerLevel < level then
		return "|cffC73C3C"..level
	else
		return "|cffff0000"..level
	end
end

-- Set the health bar on the tooltip to be a bit taller, and change the graphic.
GameTooltipStatusBar:SetHeight(12)
GameTooltipStatusBar:SetStatusBarTexture("Interface\\AddOns\\knUI\\resources\\graphics\\BantoBar.tga")

GameTooltip:HookScript("OnShow", function()
	local name = UnitPVPName("mouseover")
	-- Unfortunatly, this is the only way I know of to fix the 'looting' mouseover issue... :(
	if not LootFrame:IsVisible() and name then
		local level = colorlvl(UnitLevel("mouseover"))
		
		-- Huzzah for shortening stuff.
		local classification = UnitClassification("mouseover")
		if classification == "normal" then classification = ""
		elseif classification == "elite" then classification = "+"
		elseif classification == "worldboss" then classification = "++"
		elseif classification == "rare" then classification = " R"
		elseif classification == "rareelite" then classification = "+ R"
		end
		
		-- Determine if the player is dead, feign, or not tapped by the player, and change the color of the name if so.
		local state = ""
		if UnitIsFeignDeath("mouseover") then
			state = "|cffDF2CD0"
		elseif UnitIsDead("mouseover") or UnitIsDeadOrGhost("mouseover") then
			state = "|cff777777"
		elseif not UnitIsTappedByPlayer("mouseover") and UnitAffectingCombat("mosueover") then
			state = "|cff777777"
		end
		
		-- Retrieve the default colors, red, gred, blue, and yellow depending on unit 'con'. Change them slightly.
		local r,g,b,a = UnitSelectionColor("mouseover")
		if r > .8 and g > .8 then r,g,b = .7, .7, .2
		elseif r > .8 then r,g,b = .7, .2, .2
		elseif g > .8 then r,g,b = .2, .7, .2
		elseif b > .8 then r,g,b = .4, .4, .8
		end
		
		GameTooltipTextLeft1:SetText(state..name.." "..level.." "..classification, r, g, b, a) -- Write line one like this: Name level classification
		
		for i = 2, GameTooltip:NumLines() do
			-- retrieve the line of text from the tooltip, starting at the second line
			local line = _G["GameTooltipTextLeft"..i]:GetText()
			local line_changed
			
			-- Used to color the guild text, or <I sell stuff> of an NPC
			local color = "|cffE8D698"
			if i == 2 then
				if UnitIsPlayer("mouseover") then
					color = "|cffffffff"
					-- Get players guild information
					local guildName, guildRankName, guildRankIndex = GetGuildInfo("mouseover")
					-- If they aren't in a guild, write 'unguilded'
					if guildName == nil then guildName = "unguilded" end
					if guildRankName == nil then guildRankName = "" else guildRankName = guildRankName.." of " end
					-- replace the tooltip line with my modified line
					_G["GameTooltipTextLeft"..i]:SetText(guildRankName..guildName)
					line_changed = true
				end
			end
			
			-- Because i want the unit level written after the name
			if string.match(line, "Level") then 
				if UnitIsPlayer("mouseover") then
				-- if unit is a player: manually take the units race and class then write it. If not, skip it, and continue.
					local race = UnitRace("mouseover") or ""
					local class, lClass = UnitClassBase("mouseover")
					class = class_colors[lClass]..class
					local pvp
					if UnitIsPVP("mouseover") then pvp = " |cffC73C3C(PvP)" else pvp = "" end
					
					-- Add the race, class, and pvp status of the unit to the tooltip
					_G["GameTooltipTextLeft"..i]:SetText("|cffDEDED0"..race.." "..class..pvp)
					line_changed = true
				else
					-- If the unit is not a player, and Level is in the text, remove the line
					_G["GameTooltipTextLeft"..i]:SetText("")
					line_changed = true
				end
			-- Remove the line with PvP text.
			elseif string.match(line, "PvP") then
				_G["GameTooltipTextLeft"..i]:SetText("")
				line_changed = true
			end
			
			-- If it's a tradeskill line, ignore it.
			if string.match(line, "Skinnable") or string.match(line, "Herbalism") or string.match(line, "Mining") then 
				line_changed = true
			end
			
			-- Write the line to the tooltip
			if not line_changed then _G["GameTooltipTextLeft"..i]:SetText(color..line) end
		end
		
		local MoT = GetUnitName("mouseovertarget")										-- Get the mouse over target's target
		if MoT == PlayerName then MoT = "|cffff0033You!" end							-- Is the target the player?
		if MoT ~= nil then GameTooltip:AddLine("\n|cffffffffTarget: "..MoT) end			-- If it mouse over target has a target, write it.
		
		GameTooltip:Show() -- Formats the tooltip with new text

		-- Add a faction icon next to the tooltip if the unit is of Horde or Alliance factions.
		local faction = UnitFactionGroup("mouseover")
		if faction == "Horde" then
			HordeIcon:Show()
		elseif faction == "Alliance" then
			AllianceIcon:Show()
		end
		
	end
end)

GameTooltip:HookScript("OnHide", function()
	HordeIcon:Hide(); AllianceIcon:Hide()
end)

function GameTooltip_SetDefaultAnchor(GameTooltip, parent)
	-- Set the tooltip anchor to the mouse cursor.
	GameTooltip:SetOwner(parent, "ANCHOR_CURSOR")
end
